==> media_proxy-test-20180810.092032-18-sources.jar: com/jz/jar/media/tool/Global.java <==
package com.jz.jar.media.tool;

import java.text.DecimalFormat;
import java.util.Calendar;

import com.jz.common.utils.datetime.TimeTools;

/**
 * @Title GlobalBean
 * @Package com.jz.jar.media.tool
 * @author tangjunfeng
 * @date 2018年8月7日 下午5:39:26
 * @version V1.0
 * 
 * 
 *           N777777777NO
 *         N7777777777777N
 *        M777777777777777N
 *        $N877777777D77777M
 *       N M77777777ONND777M
 *       MN777777777NN  D777
 *     N7ZN777777777NN ~M7778
 *    N777777777777MMNN88777N
 *    N777777777777MNZZZ7777O
 *    DZN7777O77777777777777
 *     N7OONND7777777D77777N
 *      8$M++++?N???$77777$
 *       M7++++N+M77777777N
 *        N77O777777777777$                              M
 *          DNNM$$$$777777N                              D
 *         N$N:=N$777N7777M                             NZ
 *        77Z::::N777777777                          ODZZZ
 *       77N::::::N77777777M                         NNZZZ$
 *     $777:::::::77777777MN                        ZM8ZZZZZ
 *     777M::::::Z7777777Z77                        N++ZZZZNN
 *    7777M:::::M7777777$777M                       $++IZZZZM
 *   M777$:::::N777777$M7777M                       +++++ZZZDN
 *     NN$::::::7777$$M777777N                      N+++ZZZZNZ
 *       N::::::N:7$O:77777777                      N++++ZZZZN
 *       M::::::::::::N77777777+                   +?+++++ZZZM
 *       8::::::::::::D77777777M                    O+++++ZZ
 *        ::::::::::::M777777777N                      O+?D
 *        M:::::::::::M77777777778                     77=
 *        D=::::::::::N7777777777N                    777
 *       INN===::::::=77777777777N                  I777N
 *      ?777N========N7777777777787M               N7777
 *      77777$D======N77777777777N777N?         N777777
 *     I77777$$$N7===M$$77777777$77777777$MMZ77777777N
 *      $$$$$$$$$$$NIZN$$$$$$$$$M$$7777777777777777ON
 *       M$$$$$$$$M    M$$$$$$$$N=N$$$$7777777$$$ND
 *      O77Z$$$$$$$     M$$$$$$$$MNI==$DNNNNM=~N
 *   7 :N MNN$$$$M$      $$$777$8      8D8I
 *     NMM.:7O           777777778
 *                       7777777MN
 *                       M NO .7:
 *                       M   :   M
 *                            8
 */
public class Global {

	/** 根据出生日期获取年龄 */
	public static Double getAge(String birthday) {
		int days = Global.getDaysDifference(birthday);
		return Double.parseDouble(new DecimalFormat("#.0").format(days / 365f));
	}

	/** 获取生日-今日的天数 */
	private static int getDaysDifference(String birthday) {
		Calendar current = Calendar.getInstance();
		Calendar ago = Calendar.getInstance();
		ago.setTimeInMillis(TimeTools.getUnixTime(birthday));
		int days = current.get(Calendar.DAY_OF_YEAR) - ago.get(Calendar.DAY_OF_YEAR);
		for (int i = ago.get(Calendar.YEAR); i < current.get(Calendar.YEAR); i++) {
			if (i % 4 == 0 && i % 100 != 0 || i % 400 == 0) { // 闰年
				days += 366;
			} else {
				days += 365;
			}
		}
		return days;
	}

}

==> media_proxy-test-20180929.053529-140-sources.jar: com/jz/jar/media/tool/Global.java <==
package com.jz.jar.media.tool;

import java.text.DecimalFormat;
import java.util.Calendar;

import org.apache.commons.lang3.tuple.Pair;

import com.jz.common.utils.datetime.TimeTools;

/**
 * @Title GlobalBean
 * @Package com.jz.jar.media.tool
 * @author tangjunfeng
 * @date 2018年8月7日 下午5:39:26
 * @version V1.0
 * 
 * 
 *           N777777777NO
 *         N7777777777777N
 *        M777777777777777N
 *        $N877777777D77777M
 *       N M77777777ONND777M
 *       MN777777777NN  D777
 *     N7ZN777777777NN ~M7778
 *    N777777777777MMNN88777N
 *    N777777777777MNZZZ7777O
 *    DZN7777O77777777777777
 *     N7OONND7777777D77777N
 *      8$M++++?N???$77777$
 *       M7++++N+M77777777N
 *        N77O777777777777$                              M
 *          DNNM$$$$777777N                              D
 *         N$N:=N$777N7777M                             NZ
 *        77Z::::N777777777                          ODZZZ
 *       77N::::::N77777777M                         NNZZZ$
 *     $777:::::::77777777MN                        ZM8ZZZZZ
 *     777M::::::Z7777777Z77                        N++ZZZZNN
 *    7777M:::::M7777777$777M                       $++IZZZZM
 *   M777$:::::N777777$M7777M                       +++++ZZZDN
 *     NN$::::::7777$$M777777N                      N+++ZZZZNZ
 *       N::::::N:7$O:77777777                      N++++ZZZZN
 *       M::::::::::::N77777777+                   +?+++++ZZZM
 *       8::::::::::::D77777777M                    O+++++ZZ
 *        ::::::::::::M777777777N                      O+?D
 *        M:::::::::::M77777777778                     77=
 *        D=::::::::::N7777777777N                    777
 *       INN===::::::=77777777777N                  I777N
 *      ?777N========N7777777777787M               N7777
 *      77777$D======N77777777777N777N?         N777777
 *     I77777$$$N7===M$$77777777$77777777$MMZ77777777N
 *      $$$$$$$$$$$NIZN$$$$$$$$$M$$7777777777777777ON
 *       M$$$$$$$$M    M$$$$$$$$N=N$$$$7777777$$$ND
 *      O77Z$$$$$$$     M$$$$$$$$MNI==$DNNNNM=~N
 *   7 :N MNN$$$$M$      $$$777$8      8D8I
 *     NMM.:7O           777777778
 *                       7777777MN
 *                       M NO .7:
 *                       M   :   M
 *                            8
 */
public class Global {
	
	/** 微课的cid */
	public static final String microClassCid = "5bdceb2f28ab995";
	
	/** 根据出生日期获取年龄 */
	public static Double getAge(String birthday) {
		int days = Global.getDaysDifference(birthday);
		return Double.parseDouble(new DecimalFormat("#.000").format(days / 365f));
	}
	
	/** 根据出生日期获取年龄 */
	public static Pair<Integer, Integer> getAgeMonth(String birthday) {
		int months = Global.getMonthDifference(birthday);
		return Pair.of(months / 12, months % 12);
	}
	
	/** 获取生日-今日的天数 */
	private static int getDaysDifference(String birthday) {
		Calendar current = Calendar.getInstance();
		Calendar ago = Calendar.getInstance();
		ago.setTimeInMillis(TimeTools.getUnixTime(birthday));
		int days = current.get(Calendar.DAY_OF_YEAR) - ago.get(Calendar.DAY_OF_YEAR);
		for (int i = ago.get(Calendar.YEAR); i < current.get(Calendar.YEAR); i++) {
			if (i % 4 == 0 && i % 100 != 0 || i % 400 == 0) { // 闰年
				days += 366;
			} else {
				days += 365;
			}
		}
		return days;
	}
	
	/** 获取生日-今日的月差数 */
	private static int getMonthDifference(String birthday) {
		Calendar current = Calendar.getInstance();
		Calendar ago = Calendar.getInstance();
		ago.setTimeInMillis(TimeTools.getUnixTime(birthday));
		int months = current.get(Calendar.YEAR) * 12 + current.get(Calendar.MONTH);
		int result = months - (ago.get(Calendar.YEAR) * 12 + ago.get(Calendar.MONTH));
		return current.get(Calendar.DAY_OF_MONTH) < ago.get(Calendar.DAY_OF_MONTH) ? result - 1 : result;
	}
	
}
